@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2002 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ typedef struct _GMimeFilterYencClass GMimeFilterYencClass;
 
 typedef enum {
 	GMIME_FILTER_YENC_DIRECTION_ENCODE,
-	GMIME_FILTER_YENC_DIRECTION_DECODE,
+	GMIME_FILTER_YENC_DIRECTION_DECODE
 } GMimeFilterYencDirection;
 
 #define GMIME_YDECODE_STATE_INIT     (0)
