@@ -78,15 +78,15 @@ extern "C" {
 /* GMIME version */
 static const guint gmime_major_version = 2;
 static const guint gmime_minor_version = 1;
-static const guint gmime_micro_version = 0;
+static const guint gmime_micro_version = 1;
 static const guint gmime_interface_age = 0;
 static const guint gmime_binary_age    = 0;
 
 #define GMIME_CHECK_VERSION(major,minor,micro)    \
-    (gmime_major_version > (major) || \
-     (gmime_major_version == (major) && gmime_minor_version > (minor)) || \
-     (gmime_major_version == (major) && gmime_minor_version == (minor) && \
-      gmime_micro_version >= (micro)))
+    (2 > (major) || \
+     (2 == (major) && 1 > (minor)) || \
+     (2 == (major) && 1 == (minor) && \
+      1 >= (micro)))
 
 
 /**
